==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.data.conversion.ical.ical4j/src/com/openexchange/data/conversion/ical/ical4j/internal/freebusy/FreeBusyAttendee.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.data.conversion.ical.ical4j.internal.freebusy;

import java.net.URISyntaxException;
import java.util.List;
import java.util.TimeZone;

import javax.mail.internet.AddressException;
import javax.mail.internet.IDNA;

import net.fortuna.ical4j.model.Property;
import net.fortuna.ical4j.model.component.VFreeBusy;
import net.fortuna.ical4j.model.property.Attendee;
import net.fortuna.ical4j.model.property.Description;

import com.openexchange.data.conversion.ical.ConversionError;
import com.openexchange.data.conversion.ical.ConversionWarning;
import com.openexchange.data.conversion.ical.ConversionWarning.Code;
import com.openexchange.data.conversion.ical.FreeBusyInformation;
import com.openexchange.data.conversion.ical.Mode;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.Participants;
import com.openexchange.groupware.contexts.Context;

/**
 * {@link FreeBusyAttendee} 
 * 
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public final class FreeBusyAttendee<T extends VFreeBusy, U extends FreeBusyInformation> extends Participants<T, U> {

    public FreeBusyAttendee() {
        super();
    }

    @Override
    public boolean isSet(U fbInfo) {
        return null != fbInfo.getAttendee();
    }

    @Override
    public void emit(Mode mode, int index, U fbInfo, T calendarComponent, List<ConversionWarning> warnings, Context ctx, Object... args) throws ConversionError {
    	Attendee attendee = new Attendee();
    	String address = fbInfo.getAttendee().getEmailAddress();
        try {
            address = IDNA.toACE(address);
			attendee.setValue("mailto:" + address);
		} catch (URISyntaxException e) {
            throw new ConversionError(index, Code.UNEXPECTED_ERROR, e, e.getMessage());
		} catch (AddressException e) {
            throw new ConversionError(index, Code.UNEXPECTED_ERROR, e, e.getMessage());
		}
        calendarComponent.getProperties().add(attendee);
    }

    @Override
    public boolean hasProperty(T calendarComponent) {
        return null != calendarComponent.getProperty(Property.ATTENDEE);
    }

    @Override
    public void parse(int index, T calendarComponent, U fbInfo, TimeZone timeZone, Context ctx, List<ConversionWarning> warnings) throws ConversionError {
    	super.parse(index, calendarComponent, fbInfo, timeZone, ctx, warnings);
    	if (null != fbInfo.getParticipants() && 0 < fbInfo.getParticipants().length) {
    		fbInfo.setAttendee(fbInfo.getParticipants()[0]);
    	}
    }
}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.data.conversion.ical.ical4j/src/com/openexchange/data/conversion/ical/ical4j/internal/freebusy/FreeBusyAttendee.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.data.conversion.ical.ical4j.internal.freebusy;

import java.net.URISyntaxException;
import java.util.List;
import java.util.TimeZone;
import javax.mail.internet.AddressException;
import javax.mail.internet.idn.IDNA;
import net.fortuna.ical4j.model.component.VFreeBusy;
import net.fortuna.ical4j.model.property.Attendee;
import com.openexchange.data.conversion.ical.ConversionError;
import com.openexchange.data.conversion.ical.ConversionWarning;
import com.openexchange.data.conversion.ical.ConversionWarning.Code;
import com.openexchange.data.conversion.ical.FreeBusyInformation;
import com.openexchange.data.conversion.ical.Mode;
import com.openexchange.data.conversion.ical.ical4j.internal.AbstractVerifyingAttributeConverter;
import com.openexchange.groupware.contexts.Context;

/**
 * {@link FreeBusyAttendee}
 *
 * Emits a {@link FreeBusyInformation}s attendee.
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class FreeBusyAttendee extends AbstractVerifyingAttributeConverter<VFreeBusy, FreeBusyInformation> {

    /**
     * Initializes a new {@link FreeBusyAttendee}.
     */
    public FreeBusyAttendee() {
        super();
    }

    @Override
    public boolean isSet(FreeBusyInformation freeBusyInformation) {
        return null != freeBusyInformation.getAttendee();
    }

    @Override
    public void emit(Mode mode, int index, FreeBusyInformation freeBusyInformation, VFreeBusy vFreeBusy, List<ConversionWarning> warnings,
        Context ctx, Object... args) throws ConversionError {
        Attendee attendee = new Attendee();
        String address = freeBusyInformation.getAttendee();
        try {
            address = IDNA.toACE(address);
            attendee.setValue("mailto:" + address);
        } catch (URISyntaxException e) {
            throw new ConversionError(index, Code.UNEXPECTED_ERROR, e, e.getMessage());
        } catch (AddressException e) {
            throw new ConversionError(index, Code.UNEXPECTED_ERROR, e, e.getMessage());
        }
        vFreeBusy.getProperties().add(attendee);
    }

    @Override
    public boolean hasProperty(VFreeBusy vFreeBusy) {
        return false;
    }

    @Override
    public void parse(int index, VFreeBusy vFreeBusy, FreeBusyInformation freeBusyInformation, TimeZone timeZone, Context ctx,
        List<ConversionWarning> warnings) throws ConversionError {
        throw new UnsupportedOperationException("not implemented");
    }

}
